import type { APIRoute } from "astro";
import nodemailer from "nodemailer";

export const prerender = false;

const sendEmailViaSMTP = async ({
  subject,
  message,
}: {
  subject: string;
  message: string;
}) => {
  // Get environment variables
  const smtpHost = process.env.SMTP_HOST
    ? process.env.SMTP_HOST
    : import.meta.env.SMTP_HOST;
  const smtpPort = process.env.SMTP_PORT
    ? parseInt(process.env.SMTP_PORT)
    : parseInt(import.meta.env.SMTP_PORT || "587");
  const smtpUser = process.env.SMTP_USER
    ? process.env.SMTP_USER
    : import.meta.env.SMTP_USER;
  const smtpPassword = process.env.SMTP_PASSWORD
    ? process.env.SMTP_PASSWORD
    : import.meta.env.SMTP_PASSWORD;
  const fromEmail = process.env.FROM_EMAIL
    ? process.env.FROM_EMAIL
    : import.meta.env.FROM_EMAIL;
  const toEmail = process.env.TO_EMAIL
    ? process.env.TO_EMAIL
    : import.meta.env.TO_EMAIL;

  if (!smtpHost || !smtpUser || !smtpPassword || !fromEmail || !toEmail) {
    throw new Error("Missing SMTP configuration environment variables");
  }

  const transporter = nodemailer.createTransport({
    host: smtpHost,
    port: smtpPort,
    secure: smtpPort === 465,
    auth: {
      user: smtpUser,
      pass: smtpPassword,
    },
  });

  try {
    await transporter.verify();

    const info = await transporter.sendMail({
      from: fromEmail,
      to: toEmail,
      subject: subject,
      text: message,
      html: `<pre>${message}</pre>`,
    });

    console.log("Message sent: %s", info.messageId);
    return { success: true, messageId: info.messageId };
  } catch (error) {
    console.error("SMTP Error:", error);
    throw error;
  }
};

export const POST: APIRoute = async ({ request }) => {
  try {
    const data = await request.json();
    const { subject, message } = data;

    if (!subject?.trim() || !message?.trim()) {
      return new Response(
        JSON.stringify({ error: "Subject and message are required" }),
        {
          status: 400,
          headers: { "Content-Type": "application/json" },
        },
      );
    }

    await sendEmailViaSMTP({ subject, message });

    return new Response(
      JSON.stringify({ success: true, message: "Email sent successfully" }),
      {
        status: 200,
        headers: { "Content-Type": "application/json" },
      },
    );
  } catch (error) {
    console.error("API Error:", error);
    return new Response(
      JSON.stringify({
        error: "Failed to send message",
        details: error instanceof Error ? error.message : "Unknown error",
      }),
      {
        status: 500,
        headers: { "Content-Type": "application/json" },
      },
    );
  }
};
